@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 from __future__ import absolute_import
 
-import gtk
+from gi.repository import Gtk
 
 from solfege import abstract
 from solfege import gu
@@ -38,6 +38,8 @@ class Teacher(abstract.Teacher):
     def __init__(self, exname):
         abstract.Teacher.__init__(self, exname)
         self.lessonfileclass = lessonfile.IdPropertyLessonfile
+        for s in 'accidentals', 'key', 'semitones', 'atonal':
+            self.m_lessonfile_defs[s] = s
     def new_question(self):
         """
         return OK or ERR_PICKY
@@ -75,16 +77,18 @@ class Teacher(abstract.Teacher):
 
 
 class Gui(abstract.LessonbasedGui):
+    # the lesson_header variable is set in the lesson file class
+    # depending on the value of header.flavour
     def __init__(self, teacher):
         abstract.LessonbasedGui.__init__(self, teacher)
         ################
         # practise_box #
         ################
-        self.g_contents = gtk.Table()
+        self.g_contents = Gtk.Table()
         hbox = gu.bHBox(self.practise_box, True, False)
-        hbox.pack_start(gtk.HBox())
-        hbox.pack_start(self.g_contents)
-        hbox.pack_start(gtk.HBox())
+        hbox.pack_start(Gtk.HBox(), True, True, 0)
+        hbox.pack_start(self.g_contents, True, True, 0)
+        hbox.pack_start(Gtk.HBox(), True, True, 0)
         self.g_contents.set_col_spacings(gu.PAD)
         self.g_contents.set_row_spacings(gu.PAD)
 
@@ -92,7 +96,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_music_displayer.set_size_request(100, -1)
         self.g_contents.attach(self.g_music_displayer, 1, 2, 1, 2)
         self.g_flashbar = gu.FlashBar()
-        self.practise_box.pack_start(self.g_flashbar, False)
+        self.practise_box.pack_start(self.g_flashbar, False, False, 0)
 
         self.std_buttons_add(
             ('new', self.new_question),
@@ -108,10 +112,10 @@ class Gui(abstract.LessonbasedGui):
         # -----------------------------------------
         self.g_select_questions_category_box, category_box= gu.hig_category_vbox(
             _("Chord types to ask"))
-        self.config_box.pack_start(self.g_select_questions_category_box, True)
+        self.config_box.pack_start(self.g_select_questions_category_box, True, True, 0)
         self.g_select_questions = QuestionNameCheckButtonTable(self.m_t)
         self.g_select_questions.initialize(4, 0)
-        category_box.pack_start(self.g_select_questions, False)
+        category_box.pack_start(self.g_select_questions, False, False, 0)
         self.g_select_questions.show()
     def update_select_question_buttons(self):
         """
@@ -145,7 +149,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_atable.destroy()
         except AttributeError:
             pass
-        self.g_atable = gtk.Table()
+        self.g_atable = Gtk.Table()
         self.g_atable.show()
         if self.m_t.m_P.header.layout_orientation == 'horiz':
             self.g_contents.attach(self.g_atable, 1, 2, 2, 3)
@@ -161,29 +165,29 @@ class Gui(abstract.LessonbasedGui):
         trows = max([len(x) for x in self.m_t.m_P.m_props.values()]) + 2
         # The column headings
         for idx, label in enumerate(self.m_t.m_P.header.qprop_labels):
-            self.g_atable.attach(gtk.Label(label), idx * 2, idx * 2 + 1, 0, 1,
-                                 xoptions=gtk.FILL, yoptions=gtk.SHRINK,
+            self.g_atable.attach(Gtk.Label(label=label), idx * 2, idx * 2 + 1, 0, 1,
+                                 xoptions=Gtk.AttachOptions.FILL, yoptions=Gtk.AttachOptions.SHRINK,
                                  xpadding=gu.PAD_SMALL)
         # Then we create the buttons used to answer.
         for x, prop in enumerate(self.m_t.m_P.header.qprops):
             for y, proplabel in enumerate(self.m_t.m_P.m_props[prop]):
-                button = gtk.Button(unicode(proplabel))
-                button.set_data('property_name', prop)
-                button.set_data('property_value', proplabel.cval)
+                button = Gtk.Button(unicode(proplabel))
+                button.m_property_name = prop
+                button.m_property_value = proplabel.cval
                 button.connect('clicked', self.on_prop_button_clicked)
                 button.connect('button_release_event', self.on_prop_button_right_clicked)
                 self.g_atable.attach(button, x * 2, x * 2 + 1, y + 2, y + 3,
                     xpadding=gu.PAD_SMALL,
-                    yoptions=gtk.SHRINK)
+                    yoptions=Gtk.AttachOptions.SHRINK)
         # The separator below the column headings
-        self.g_atable.attach(gtk.HSeparator(), 0, tcols, 1, 2,
-            xoptions=gtk.FILL, yoptions=gtk.FILL,
+        self.g_atable.attach(Gtk.HSeparator(), 0, tcols, 1, 2,
+            xoptions=Gtk.AttachOptions.FILL, yoptions=Gtk.AttachOptions.FILL,
             xpadding=0, ypadding=gu.PAD_SMALL)
         # The vertical separator between columns
         for idx in range(len(self.m_t.m_P.header.qprops)-1):
-            self.g_atable.attach(gtk.VSeparator(),
+            self.g_atable.attach(Gtk.VSeparator(),
             idx * 2 + 1, idx * 2 + 2, 0, trows,
-            xoptions=gtk.FILL, yoptions=gtk.FILL,
+            xoptions=Gtk.AttachOptions.FILL, yoptions=Gtk.AttachOptions.FILL,
             xpadding=0, ypadding=gu.PAD_SMALL)
         self.g_atable.show_all()
         #
@@ -191,13 +195,15 @@ class Gui(abstract.LessonbasedGui):
     def on_prop_button_clicked(self, button):
         if self.m_t.q_status != self.QSTATUS_NEW:
             return
-        g = self.m_t.guess_property(button.get_data('property_name'),
-                                    button.get_data('property_value'))
+        g = self.m_t.guess_property(button.m_property_name,
+                                    button.m_property_value)
         if g:
             self.g_flashbar.flash(_("Correct"))
             for btn in self.g_atable.get_children():
-                if btn.get_data('property_name') == button.get_data('property_name')\
-                 and btn.get_data('property_value') == button.get_data('property_value'):
+                if not isinstance(btn, Gtk.Button):
+                    continue
+                if btn.m_property_name == button.m_property_name \
+                 and btn.m_property_value == button.m_property_value:
                     btn.get_children()[0].set_name("BoldText")
                     break
             if g == self.m_t.ALL_CORRECT:
@@ -222,7 +228,7 @@ class Gui(abstract.LessonbasedGui):
         for k in self.m_t.m_P.header.qprops:
             d[k] = self.m_t.m_P.get_question()[k].cval
         # replace one property with the one we right clicked
-        d[button.get_data('property_name')] = button.get_data('property_value')
+        d[button.m_property_name] = button.m_property_value
         for idx, question in enumerate(self.m_t.m_P.m_questions):
             match = True
             for k in d:
@@ -243,12 +249,9 @@ class Gui(abstract.LessonbasedGui):
             soundcard.synth.stop()
             self.std_buttons_exception_cleanup()
             self.m_t.q_status = self.QSTATUS_NO
-        # if we have no lessonfile, then we have to questions.
-        if not self.m_t.m_P:
-            return
         # make sure all buttons are sensitive.
         for x in self.g_atable.get_children():
-            if isinstance(x, gtk.Button):
+            if isinstance(x, Gtk.Button):
                 # Set name to "" to make all labels not have bold text.
                 x.get_children()[0].set_name("")
         ##
@@ -264,20 +267,17 @@ class Gui(abstract.LessonbasedGui):
             self.m_t.m_P.play_question()
             self.std_buttons_new_question()
             self.g_give_up.set_sensitive(True)
-            [btn for btn in self.g_atable.get_children() if isinstance(btn, gtk.Button)][-1].grab_focus()
+            [btn for btn in self.g_atable.get_children() if isinstance(btn, Gtk.Button)][-1].grab_focus()
         except Exception, e:
             if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def on_start_practise(self):
         self.m_t.m_custom_mode = self.get_bool('gui/expert_mode')
+        super(Gui, self).on_start_practise()
         for question in self.m_t.m_P.m_questions:
             question.active = 1
         self.g_music_displayer.clear()
         self.update_select_question_buttons()
-        if self.m_t.m_P.header.lesson_heading:
-            self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
-        else:
-            self.set_lesson_heading("")
         if self.m_t.m_P.header.new_button_label:
             self.g_new.set_label(self.m_t.m_P.header.new_button_label)
         else:
@@ -302,8 +302,8 @@ class Gui(abstract.LessonbasedGui):
             self.run_exception_handled(self.show_answer)
             self.std_buttons_give_up()
             for button in self.g_atable.get_children():
-                if isinstance(button, gtk.Button):
-                    if button.get_data('property_value') == self.m_t.m_P.get_question()[button.get_data('property_name')].cval:
+                if isinstance(button, Gtk.Button):
+                    if button.m_property_value == self.m_t.m_P.get_question()[button.m_property_name].cval:
                         button.get_children()[0].set_name('BoldText')
                     else:
                         button.get_children()[0].set_name('')
