@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8:
 # GNU Solfege - free ear training software
-# Copyright (C) 2010  Tom Cato Amundsen
+# Copyright (C) 2010, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,14 +59,14 @@ class Teacher(abstract.Teacher):
         if 'rhythm' in self.m_P.get_question():
             music_obj = self.m_P.get_question()['rhythm']
             if not isinstance(music_obj, lessonfile.MpdParsable):
-                raise lessonfile.LessonfileException(_("The music object named «rhythm» is not a subclass of MpdParsable"),
-                'Read about the «rhythm» variable in the section «Question block» in the chapter named «Extending GNU Solfege» in the users manual.')
+                raise lessonfile.LessonfileException(_(u"The music object named «rhythm» is not a subclass of MpdParsable"),
+                _(u'Read about the «rhythm» variable in the section «Question block» in the chapter named «Extending GNU Solfege» in the user manual.'))
             music = music_obj.get_mpd_music_string(self.m_P)
         else:
             music_obj = self.m_P.get_question()['music']
             if not isinstance(music_obj, lessonfile.MpdParsable):
                 raise lessonfile.LessonfileException(_("The music object named «music» is not a subclass of MpdParsable"),
-                'Read about the «rhythm» variable in the section «Question block» in the chapter named «Extending GNU Solfege» in the users manual.')
+                _('Read about the «rhythm» variable in the section «Question block» in the chapter named «Extending GNU Solfege» in the user manual.'))
             music = music_obj.get_mpd_music_string(self.m_P)
         for bar in mpd.parser.parse_to_score_object(music).m_bars:
             if isinstance(bar, elems.PartialBar):
@@ -98,6 +98,7 @@ class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher):
         abstract.LessonbasedGui.__init__(self, teacher)
         self.g_w = mpd.RhythmWidget()
+        self.g_w.connect('score-updated', self.on_score_updated)
         self.practise_box.pack_start(self.g_w, False)
         self.g_c = mpd.RhythmWidgetController(self.g_w)
         self.practise_box.pack_start(self.g_c, False)
@@ -110,6 +111,8 @@ class Gui(abstract.LessonbasedGui):
             ('repeat', self.repeat_question),
             ('give_up', self.give_up))
         self.g_w.show()
+    def on_score_updated(self, w):
+        self.g_guess_answer.set_sensitive(bool(self.g_w.m_score.get_timelist()))
     def new_question(self, *w):
         def exception_cleanup():
             self.m_t.q_status = self.QSTATUS_NO
